@@ -12,9 +12,10 @@ from cgi import FieldStorage
 from omnitools import dt2yyyymmddhhmmss, ApacheHeadersDict, str2html
 
 
-if "REDIRECT_QUERY_STRING" in os.environ and not os.environ["QUERY_STRING"]:
-    os.environ["QUERY_STRING"] = os.environ["REDIRECT_QUERY_STRING"]
 _SERVER = dict(os.environ)
+for k in _SERVER:
+    if _SERVER[k].startswith("REDIRECT_"):
+        _SERVER[k.replace("REDIRECT_", "")] = _SERVER[k]
 arguments = FieldStorage(environ=os.environ)
 arguments = {k: [_.value for _ in arguments[k]] if isinstance(arguments[k], list) else arguments[k].value for k in arguments}
 _GET = arguments
